@@ -33,6 +33,16 @@ struct _SpApplication
 
 G_DEFINE_TYPE (SpApplication, sp_application, GTK_TYPE_APPLICATION)
 
+struct {
+  const gchar *action_name;
+  const gchar *accels[12];
+} default_accels[] = {
+  { "zoom.zoom-in", { "<Primary>plus", "<Primary>KP_Add", "<Primary>equal", "ZoomIn", NULL } },
+  { "zoom.zoom-out", { "<Primary>minus", "<Primary>KP_Subtract", "ZoomOut", NULL } },
+  { "zoom.zoom-one", { "<Primary>0", "<Primary>KP_0", NULL } },
+  { NULL }
+};
+
 static void
 sp_application_activate (GApplication *app)
 {
@@ -90,7 +100,7 @@ sp_application_open (GApplication  *app,
 static void
 sp_application_startup (GApplication *application)
 {
-  GtkCssProvider *provider;
+  g_autoptr(GtkCssProvider) provider = NULL;
 
   g_assert (SP_IS_APPLICATION (application));
 
@@ -101,7 +111,11 @@ sp_application_startup (GApplication *application)
   gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
                                              GTK_STYLE_PROVIDER (provider),
                                              GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-  g_clear_object (&provider);
+
+  for (guint i = 0; default_accels[i].action_name; i++)
+    gtk_application_set_accels_for_action (GTK_APPLICATION (application),
+                                           default_accels[i].action_name,
+                                           default_accels[i].accels);
 }
 
 static void
@@ -249,15 +263,52 @@ sysprof_open_capture (GSimpleAction *action,
   sp_window_open_from_dialog (SP_WINDOW (window));
 }
 
+static void
+sysprof_show_help_overlay (GSimpleAction *action,
+                           GVariant      *variant,
+                           gpointer       user_data)
+{
+  GtkApplication *app = user_data;
+  SpWindow *window = NULL;
+
+  g_assert (G_IS_APPLICATION (app));
+  g_assert (G_IS_SIMPLE_ACTION (action));
+  g_assert (variant == NULL);
+
+  for (GList *list = gtk_application_get_windows (app); list; list = list->next)
+    {
+      GtkWindow *element = list->data;
+
+      if (SP_IS_WINDOW (element))
+        {
+          window = SP_WINDOW (element);
+          break;
+        }
+    }
+
+  if (window == NULL)
+    {
+      window = g_object_new (SP_TYPE_WINDOW,
+                             "application", app,
+                             NULL);
+      gtk_window_present (GTK_WINDOW (window));
+    }
+
+  g_assert (g_action_group_has_action (G_ACTION_GROUP (window), "show-help-overlay"));
+
+  g_action_group_activate_action (G_ACTION_GROUP (window), "show-help-overlay", NULL);
+}
+
 static void
 sp_application_init (SpApplication *self)
 {
   static const GActionEntry actions[] = {
-    { "about",        sysprof_about },
-    { "new-window",   sysprof_new_window },
-    { "open-capture", sysprof_open_capture },
-    { "help",         sysprof_help },
-    { "quit",         sysprof_quit },
+    { "about",             sysprof_about },
+    { "new-window",        sysprof_new_window },
+    { "open-capture",      sysprof_open_capture },
+    { "help",              sysprof_help },
+    { "show-help-overlay", sysprof_show_help_overlay },
+    { "quit",              sysprof_quit },
   };
 
   g_action_map_add_action_entries (G_ACTION_MAP (self), actions, G_N_ELEMENTS (actions), self);
