@@ -212,6 +212,8 @@ sp_window_build_profile_cb (GObject      *object,
   g_assert (SP_IS_WINDOW (self));
   g_assert (G_IS_ASYNC_RESULT (result));
 
+  gtk_widget_set_sensitive (GTK_WIDGET (self->record_button), TRUE);
+
   if (!sp_profile_generate_finish (profile, result, &error))
     {
       /* If we were cancelled while updating the selection, ignore the failure */
@@ -257,6 +259,8 @@ sp_window_build_profile (SpWindow *self)
 
   self->refilter_cancellable = g_cancellable_new ();
 
+  gtk_widget_set_sensitive (GTK_WIDGET (self->record_button), FALSE);
+
   sp_profile_generate (profile,
                        self->refilter_cancellable,
                        sp_window_build_profile_cb,
